# SchoolScheduler

School Scheduler is a utility designed to help High School administrator create student, teacher, and classroom schedules. This task is usually done by hand or in unoptimized programs such as excel. We leverage the computational power of a computer to check thousands of potential schedules per second.   

<h1>Major Features:</h1>

Bulk import/export of student schedules.
Easy PDF export for mass printing
Keeps Track of Students Graduation Requirement to Recommend schedules
Easily make modifications using our intuitive UI

pip information TBA

How to use program
***NOTE Current Beta Modifications***
Student data is artificially generated upto 100 students for performance until we migrate algorithm to C++

Release Version

1.00V
6/28/21

Contributors:

Justin Miller

Julian Berrio

Navid Ali

Megan Quinn

Michael Berry


GITHUB: https://github.com/jaberrio/SchoolScheduler


